@@ -21,16 +21,16 @@
 
 #include "keditlistwidget.h"
 
-#include <QtCore/QStringList>
+#include <QStringList>
 #include <QKeyEvent>
-#include <QLabel>
-#include <QLayout>
 #include <QLineEdit>
 #include <QListView>
 #include <QPushButton>
 #include <QApplication>
 #include <QComboBox>
 #include <QStringListModel>
+#include <QVBoxLayout>
+#include <QHBoxLayout>
 
 class KEditListWidgetPrivate
 {
@@ -75,7 +75,7 @@ void KEditListWidgetPrivate::init(bool check, KEditListWidget::Buttons newButton
                                  QSizePolicy::Preferred));
 
     mainLayout = new QVBoxLayout(q);
-    mainLayout->setMargin(0);
+    mainLayout->setContentsMargins(0, 0, 0, 0);
 
     QHBoxLayout *subLayout = new QHBoxLayout;
     btnsLayout = new QVBoxLayout;
