@@ -21,27 +21,19 @@
 #include "kmimetypeeditor.h"
 #include <qmimedatabase.h>
 
-#include <QApplication>
 #include <QDialogButtonBox>
 #include <QLabel>
-#include <QLayout>
 #include <QPushButton>
 #include <QStandardPaths>
 #include <QTreeWidget>
-
-static const QString i18n(const char *a)
-{
-    return QApplication::translate("KMimeTypeChooser", a);
-}
+#include <QVBoxLayout>
 
 //BEGIN KMimeTypeChooserPrivate
 class KMimeTypeChooserPrivate
 {
 public:
     KMimeTypeChooserPrivate(KMimeTypeChooser *parent)
-        : q(parent),
-          mimeTypeTree(0),
-          btnEditMimeType(0)
+        : q(parent)
     {
     }
 
@@ -52,8 +44,8 @@ public:
     void _k_slotSycocaDatabaseChanged(const QStringList &);
 
     KMimeTypeChooser *q;
-    QTreeWidget *mimeTypeTree;
-    QPushButton *btnEditMimeType;
+    QTreeWidget *mimeTypeTree = nullptr;
+    QPushButton *btnEditMimeType = nullptr;
 
     QString defaultgroup;
     QStringList groups;
@@ -83,7 +75,7 @@ KMimeTypeChooser::KMimeTypeChooser(const QString &text,
     d->visuals = visuals;
 
     QVBoxLayout *vboxLayout = new QVBoxLayout(this);
-    vboxLayout->setMargin(0);
+    vboxLayout->setContentsMargins(0, 0, 0, 0);
     if (!text.isEmpty()) {
         vboxLayout->addWidget(new QLabel(text, this));
     }
@@ -91,13 +83,13 @@ KMimeTypeChooser::KMimeTypeChooser(const QString &text,
     d->mimeTypeTree = new QTreeWidget(this);
     vboxLayout->addWidget(d->mimeTypeTree);
     QStringList headerLabels;
-    headerLabels.append(i18n("Mime Type"));
+    headerLabels.append(tr("Mime Type"));
 
     if (visuals & Comments) {
-        headerLabels.append(i18n("Comment"));
+        headerLabels.append(tr("Comment"));
     }
     if (visuals & Patterns) {
-        headerLabels.append(i18n("Patterns"));
+        headerLabels.append(tr("Patterns"));
     }
 
     d->mimeTypeTree->setColumnCount(headerLabels.count());
@@ -110,18 +102,18 @@ KMimeTypeChooser::KMimeTypeChooser(const QString &text,
     if (visuals & EditButton) {
         QHBoxLayout *buttonLayout = new QHBoxLayout();
         buttonLayout->addStretch(1);
-        d->btnEditMimeType = new QPushButton(i18n("&Edit..."), this);
+        d->btnEditMimeType = new QPushButton(tr("&Edit..."), this);
         buttonLayout->addWidget(d->btnEditMimeType);
 
-        connect(d->btnEditMimeType, SIGNAL(clicked()), this, SLOT(_k_editMimeType()));
+        connect(d->btnEditMimeType, &QPushButton::clicked, this, [this]() { d->_k_editMimeType(); });
         d->btnEditMimeType->setEnabled(false);
-        connect(d->mimeTypeTree, SIGNAL(itemDoubleClicked(QTreeWidgetItem*,int)),
-                this, SLOT(_k_editMimeType()));
+        connect(d->mimeTypeTree, &QTreeWidget::itemDoubleClicked,
+                this, [this]() { d->_k_editMimeType(); });
         connect(d->mimeTypeTree, SIGNAL(currentItemChanged(QTreeWidgetItem*,QTreeWidgetItem*)),
                 this, SLOT(_k_slotCurrentChanged(QTreeWidgetItem*)));
 
-        d->btnEditMimeType->setWhatsThis(i18n(
-                                             "Click this button to display the familiar KDE mime type editor."));
+        d->btnEditMimeType->setWhatsThis(tr(
+                                            "Click this button to display the familiar KDE mime type editor."));
 
         vboxLayout->addLayout(buttonLayout);
     }
@@ -150,10 +142,10 @@ void KMimeTypeChooserPrivate::loadMimeTypes(const QStringList &_selectedMimeType
     const QList<QMimeType> mimetypes = db.allMimeTypes();
 
     bool agroupisopen = false;
-    QTreeWidgetItem *idefault = 0; //open this, if all other fails
-    QTreeWidgetItem *firstChecked = 0; // make this one visible after the loop
+    QTreeWidgetItem *idefault = nullptr; //open this, if all other fails
+    QTreeWidgetItem *firstChecked = nullptr; // make this one visible after the loop
 
-    foreach (const QMimeType &mt, mimetypes) {
+    for (const QMimeType &mt : mimetypes) {
         const QString mimetype = mt.name();
         const int index = mimetype.indexOf(QLatin1Char('/'));
         const QString maj = mimetype.left(index);
@@ -186,7 +178,7 @@ void KMimeTypeChooserPrivate::loadMimeTypes(const QStringList &_selectedMimeType
         }
 
         if (visuals & KMimeTypeChooser::Patterns) {
-            item->setText(cl, mt.globPatterns().join(QStringLiteral("; ")));
+            item->setText(cl, mt.globPatterns().join(QLatin1String("; ")));
         }
 
         if (selMimeTypes.contains(mimetype)) {
@@ -238,7 +230,7 @@ void KMimeTypeChooserPrivate::_k_slotCurrentChanged(QTreeWidgetItem *item)
 // TODO: see _k_editMimeType
 void KMimeTypeChooserPrivate::_k_slotSycocaDatabaseChanged(const QStringList &changedResources)
 {
-    if (changedResources.contains(QStringLiteral("xdgdata-mime"))) {
+    if (changedResources.contains(QLatin1String("xdgdata-mime"))) {
         loadMimeTypes();
     }
 }
@@ -270,7 +262,8 @@ QStringList KMimeTypeChooser::mimeTypes() const
     QStringList mimeList;
     QList<QTreeWidgetItem *> checkedItems;
     getCheckedItems(checkedItems, d->mimeTypeTree);
-    foreach (QTreeWidgetItem *item, checkedItems) {
+    mimeList.reserve(checkedItems.size());
+    for (QTreeWidgetItem *item : qAsConst(checkedItems)) {
         mimeList.append(item->parent()->text(0) + QLatin1Char('/') + item->text(0));
     }
     return mimeList;
@@ -282,7 +275,7 @@ QStringList KMimeTypeChooser::patterns() const
     QList<QTreeWidgetItem *> checkedItems;
     getCheckedItems(checkedItems, d->mimeTypeTree);
     QMimeDatabase db;
-    foreach (QTreeWidgetItem *item, checkedItems) {
+    for (QTreeWidgetItem *item : qAsConst(checkedItems)) {
         QMimeType mime = db.mimeTypeForName(item->parent()->text(0) + QLatin1Char('/') + item->text(0));
         Q_ASSERT(mime.isValid());
         patternList += mime.globPatterns();
@@ -293,7 +286,7 @@ QStringList KMimeTypeChooser::patterns() const
 
 //BEGIN KMimeTypeChooserDialog::Private
 
-class KMimeTypeChooserDialog::Private
+class Q_DECL_HIDDEN KMimeTypeChooserDialog::Private
 {
 public:
     Private(KMimeTypeChooserDialog *parent)
@@ -359,8 +352,8 @@ void KMimeTypeChooserDialog::Private::init()
 
     QDialogButtonBox *buttonBox = new QDialogButtonBox(q);
     buttonBox->setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
-    QObject::connect(buttonBox, SIGNAL(accepted()), q, SLOT(accept()));
-    QObject::connect(buttonBox, SIGNAL(rejected()), q, SLOT(reject()));
+    QObject::connect(buttonBox, &QDialogButtonBox::accepted, q, &QDialog::accept);
+    QObject::connect(buttonBox, &QDialogButtonBox::rejected, q, &QDialog::reject);
     layout->addWidget(buttonBox);
 }
 
